/*
 * Copyright 2012 Martin Skurla
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 */
package org.crazyjavahacking.astvisualizer.netbeans;


import lombok.Getter;
import lombok.Setter;


/**
 * AST Graph Scene configuration.<br />
 * Default constructor will create default configuration:
 * <ul>
 *     <li>originX = 25</li>
 *     <li>originY = 25</li>
 *     <li>gapBetweenLevels = 50</li>
 *     <li>gapBetweenNodes  = 50</li>
 *     <li>rootNodeLocation = TOP</li>
 * </ul>
 *
 * @author Martin Skurla (crazyjavahacking@gmail.com)
 *
 * @since 1.0.2
 */
@Getter
@Setter
public final class ASTGraphSceneConfiguration {

    //-----------------------------------------------------------------------------------------------------------------
    // Members.
    //-----------------------------------------------------------------------------------------------------------------
    private int originX = 25;
    private int originY = 25;

    private double gapBetweenLevels = 50;
    private double gapBetweenNodes  = 50;

    private RootNodeLocation rootNodeLocation = RootNodeLocation.TOP;


    //-----------------------------------------------------------------------------------------------------------------
    // Inner classes.
    //-----------------------------------------------------------------------------------------------------------------
    public static enum RootNodeLocation {
        TOP,
        BOTTOM,
        LEFT,
        RIGHT
    }
}
